Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(147)

Unified Diff: third_party/WebKit/Source/core/css/cssom/CSSTranslation.h

Issue 1958933003: Typed CSSOM: Rename Translation to CSSTranslation (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebase Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/css/cssom/CSSTranslation.h
diff --git a/third_party/WebKit/Source/core/css/cssom/TranslationTransformComponent.h b/third_party/WebKit/Source/core/css/cssom/CSSTranslation.h
similarity index 64%
rename from third_party/WebKit/Source/core/css/cssom/TranslationTransformComponent.h
rename to third_party/WebKit/Source/core/css/cssom/CSSTranslation.h
index 9e8442162ca5ac7ccb115b7dad309831fae32069..5bcd47d72540d546c4be12d438ddcaecd581118a 100644
--- a/third_party/WebKit/Source/core/css/cssom/TranslationTransformComponent.h
+++ b/third_party/WebKit/Source/core/css/cssom/CSSTranslation.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef TranslationTransformComponent_h
-#define TranslationTransformComponent_h
+#ifndef CSSTranslation_h
+#define CSSTranslation_h
#include "core/css/cssom/LengthValue.h"
#include "core/css/cssom/TransformComponent.h"
@@ -12,15 +12,15 @@ namespace blink {
class ExceptionState;
-class CORE_EXPORT TranslationTransformComponent final : public TransformComponent {
- WTF_MAKE_NONCOPYABLE(TranslationTransformComponent);
+class CORE_EXPORT CSSTranslation final : public TransformComponent {
+ WTF_MAKE_NONCOPYABLE(CSSTranslation);
DEFINE_WRAPPERTYPEINFO();
public:
- static TranslationTransformComponent* create(LengthValue* x, LengthValue* y, ExceptionState&)
+ static CSSTranslation* create(LengthValue* x, LengthValue* y, ExceptionState&)
{
- return new TranslationTransformComponent(x, y, nullptr);
+ return new CSSTranslation(x, y, nullptr);
}
- static TranslationTransformComponent* create(LengthValue* x, LengthValue* y, LengthValue* z, ExceptionState&);
+ static CSSTranslation* create(LengthValue* x, LengthValue* y, LengthValue* z, ExceptionState&);
LengthValue* x() const { return m_x; }
LengthValue* y() const { return m_y; }
@@ -28,7 +28,7 @@ public:
TransformComponentType type() const override { return is2D() ? TranslationType : Translation3DType; }
// TODO: Implement asMatrix for TranslationTransformComponent.
MatrixTransformComponent* asMatrix() const override { return nullptr; }
CSSFunctionValue* toCSSValue() const override;
@@ -42,7 +42,7 @@ public:
}
private:
- TranslationTransformComponent(LengthValue* x, LengthValue* y, LengthValue* z)
+ CSSTranslation(LengthValue* x, LengthValue* y, LengthValue* z)
: TransformComponent()
, m_x(x)
, m_y(y)
@@ -28,7 +28,7 @@ public:
TransformComponentType type() const override { return is2D() ? TranslationType : Translation3DType; }
- // TODO: Implement asMatrix for TranslationTransformComponent.
+ // TODO: Implement asMatrix for CSSTranslation.
MatrixTransformComponent* asMatrix() const override { return nullptr; }
CSSFunctionValue* toCSSValue() const override;
« no previous file with comments | « third_party/WebKit/Source/core/core.gypi ('k') | third_party/WebKit/Source/core/css/cssom/CSSTranslation.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698